PRAGMA foreign_keys = ON;

CREATE TABLE IF NOT EXISTS publishers (
id            INTEGER NOT NULL UNIQUE ON CONFLICT IGNORE,
name          TEXT    NOT NULL
);
CREATE UNIQUE INDEX IF NOT EXISTS id ON publishers(id);

CREATE TABLE IF NOT EXISTS apps (
id                    INTEGER NOT NULL UNIQUE ON CONFLICT IGNORE,
bundle_id             TEXT    NOT NULL UNIQUE ON CONFLICT IGNORE,
name                  TEXT    NOT NULL,
publisher_id          INTEGER NOT NULL,
platform              INTEGER NOT NULL,
icon_remote_url_lores TEXT    NOT NULL UNIQUE ON CONFLICT IGNORE,
icon_remote_url_hires TEXT    NOT NULL UNIQUE ON CONFLICT IGNORE
);
CREATE UNIQUE INDEX IF NOT EXISTS id ON apps(id);

CREATE TABLE IF NOT EXISTS authors (
id   INTEGER NOT NULL UNIQUE ON CONFLICT IGNORE,
name TEXT    NOT NULL
);
CREATE UNIQUE INDEX IF NOT EXISTS id ON authors(id);

CREATE TABLE IF NOT EXISTS reviews (
id                    INTEGER NOT NULL UNIQUE ON CONFLICT IGNORE,
app_id                INTEGER NOT NULL REFERENCES apps(id) ON DELETE CASCADE DEFERRABLE INITIALLY DEFERRED,
author_id             INTEGER NOT NULL REFERENCES authors(id) ON DELETE CASCADE DEFERRABLE INITIALLY DEFERRED,
date                  INTEGER NOT NULL,
country               TEXT    NOT NULL,
version               TEXT    NOT NULL,
version_sortable      INTEGER,
title                 TEXT,
content               TEXT,
rating                INTEGER NOT NULL,
useful_votes_overall  INTEGER NOT NULL,
useful_votes_positive INTEGER NOT NULL,
is_read               INTEGER,
is_favorited          INTEGER,
note                  TEXT,
translation_language  TEXT,
translated_title      TEXT,
translated_title_service TEXT,
translated_content       TEXT,
translated_content_service TEXT
);
CREATE UNIQUE INDEX IF NOT EXISTS id          ON reviews (id);
CREATE        INDEX IF NOT EXISTS by_app_date ON reviews (app_id,date);
CREATE        INDEX IF NOT EXISTS by_author   ON reviews (author_id);

CREATE TABLE IF NOT EXISTS updates (
id                    INTEGER PRIMARY KEY AUTOINCREMENT UNIQUE NOT NULL,
date                  INTEGER NOT NULL,
app_id                INTEGER NOT NULL,
country_code          TEXT    NOT NULL,
last_review_id        INTEGER,
number_of_reviews     INTEGER NOT NULL,
trigger               INTEGER NOT NULL,
data_was_valid        INTEGER NOT NULL
);
CREATE        INDEX IF NOT EXISTS by_app ON updates(app_id,country_code);

CREATE TABLE IF NOT EXISTS daily_summary (
id                    INTEGER PRIMARY KEY AUTOINCREMENT UNIQUE NOT NULL,
app_id                INTEGER NOT NULL,
date                  TEXT NOT NULL,
rating                INTEGER NOT NULL,
count                 INTEGER NOT NULL,
CONSTRAINT enforce_unique UNIQUE (app_id, date, rating) ON CONFLICT REPLACE
);
CREATE UNIQUE INDEX IF NOT EXISTS id ON daily_summary (id);

CREATE TABLE IF NOT EXISTS version_summary (
id                    INTEGER PRIMARY KEY AUTOINCREMENT UNIQUE NOT NULL,
app_id                INTEGER NOT NULL,
version               TEXT NOT NULL,
average               REAL,
count                 INTEGER,
count_1               INTEGER,
count_2               INTEGER,
count_3               INTEGER,
count_4               INTEGER,
count_5               INTEGER,
median                REAL,
q25                   REAL,
q75                   REAL,
CONSTRAINT enforce_unique UNIQUE (app_id, version) ON CONFLICT REPLACE
);
CREATE UNIQUE INDEX IF NOT EXISTS id ON version_summary (id);
CREATE        INDEX IF NOT EXISTS by_app_version ON version_summary (app_id,version);
